==> haskell-microlens-ghc-0.4.8.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.8.0
id: microlens-ghc-0.4.8.0-Ievlk22npCk69ALZCC0Cgz
key: microlens-ghc-0.4.8.0-Ievlk22npCk69ALZCC0Cgz
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
abi: 90b929def13eaabaee9bfa6be5aab4bf
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-ghc-0.4.8.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-ghc-0.4.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/microlens-ghc-0.4.8.0
hs-libraries: HSmicrolens-ghc-0.4.8.0-Ievlk22npCk69ALZCC0Cgz
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    microlens-0.4.8.0-5PXN9DedWooJg6UJ24ter0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-ghc-0.4.8.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.8.0
id: microlens-ghc-0.4.8.0-5qd8myS6x2Z3CN7myyWRzG
key: microlens-ghc-0.4.8.0-5qd8myS6x2Z3CN7myyWRzG
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
abi: 1317f07ade95a2c1a030b0cb38d1d384
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-ghc-0.4.8.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-ghc-0.4.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/microlens-ghc-0.4.8.0
hs-libraries: HSmicrolens-ghc-0.4.8.0-5qd8myS6x2Z3CN7myyWRzG
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    microlens-0.4.8.1-BVhsezHoPw9Ez18LAXVtpM transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
